4Suite API Documentation: Ft.Lib.DistExt.Formatters.XmlFormatter

4Suite™ API Documentation

# ► Module Ft.Lib.DistExt.Formatters.XmlFormatter

Classes: XmlFormatter, XmlRepr

## Classes

class XmlFormatter(XmlRepr)

  ### Methods

  __init__(self, dist_command)
    Overrides: __init__ from class XmlRepr
  document(self, object)
  end_element(self, tagname)
  format(self, object, stream, encoding=None)
    Print documentation for a Python object to a stream.
  section(self, title, list, format)
  start_element(self, tagname, attributes={})
  warn(self, msg)
  write_element(self, tagname, attributes={}, content='')

  ### Methods inherited from class XmlRepr

  escape, repr, repr_str, repr_unicode

  ### Methods inherited from class pydoc.TextRepr

  repr1, repr_instance, repr_string

  ### Methods inherited from class repr.Repr

  repr_array, repr_deque, repr_dict, repr_frozenset, repr_list, repr_long, repr_set, repr_tuple

  ### Members

  document_type = None
  indent = ' '
class XmlRepr(pydoc.TextRepr)
  Class for safely making a XML representation of a Python object.

  ### Methods

  escape(self, text)
  repr(self, object)
    Overrides: repr from class TextRepr
  repr_str = repr_string(self, x, level)
    Overrides: repr_str from class TextRepr
  repr_unicode = repr_string(self, x, level)

  ### Methods inherited from class pydoc.TextRepr

  __init__, repr1, repr_instance, repr_string

  ### Methods inherited from class repr.Repr

  repr_array, repr_deque, repr_dict, repr_frozenset, repr_list, repr_long, repr_set, repr_tuple